// importing necessary modules I used for this graph.
import { getData } from './getData';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// declaring constants by reading svg tag from index.html
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.5~g')(number);

// Start building pie graph
const render = (data,total) => {
  const pieData = pie().value(d=>d.TotalDeaths)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(["#4b4b4b", "#9acbc2", "#f2a0ea", "#014140", "#d9d5d5","#FFD700", "#B22222",
      "#0000FF", "#f58026", "#00b5cc"]);
  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(170)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.TotalDeaths));
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*25})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.TotalDeaths));
  
   sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.TotalDeaths/1000))+"K")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);

  legend.append("text")
  	.attr("x", 30)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.TotalDeaths)));
}

const run = async () => {
  let data = await getData()
  let total = 0
  data.forEach(d=>{
    d.TotalDeaths = +d.TotalDeaths;
    total += d.TotalDeaths
  });
  console.log(data)
	render(data,total);
};
run();